@@ -42,6 +42,7 @@ DEFAULT_EXTENSIONS = [
 
 
 JINJA2_FILTERS.update({
+    'static': "django_jinja.builtins.filters.static",
     'reverseurl': "django_jinja.builtins.filters.reverse",
     'addslashes': "django_jinja.builtins.filters.addslashes",
     'capfirst': "django_jinja.builtins.filters.capfirst",
@@ -198,33 +199,22 @@ class Environment(Environment):
 
         if self.autoescape:
             from django.utils import safestring
+
             if hasattr(safestring, "SafeText"):
                 if not hasattr(safestring.SafeText, '__html__'):
-                    if sys.version_info.major < 3:
-                        safestring.SafeText.__html__ = lambda self: unicode(self)
-                    else:
-                        safestring.SafeText.__html__ = lambda self: str(self)
+                    safestring.SafeText.__html__ = lambda self: six.text_type(self)
 
             if hasattr(safestring, "SafeString"):
                 if not hasattr(safestring.SafeString, '__html__'):
-                    if sys.version_info.major < 3:
-                        safestring.SafeString.__html__ = lambda self: unicode(self)
-                    else:
-                        safestring.SafeString.__html__ = lambda self: str(self)
+                    safestring.SafeString.__html__ = lambda self: six.text_type(self)
 
             if hasattr(safestring, "SafeUnicode"):
                 if not hasattr(safestring.SafeUnicode, '__html__'):
-                    if sys.version_info.major < 3:
-                        safestring.SafeUnicode.__html__ = lambda self: unicode(self)
-                    else:
-                        safestring.SafeUnicode.__html__ = lambda self: str(self)
+                    safestring.SafeUnicode.__html__ = lambda self: six.text_type(self)
 
             if hasattr(safestring, "SafeBytes"):
                 if not hasattr(safestring.SafeBytes, '__html__'):
-                    if sys.version_info.major < 3:
-                        safestring.SafeBytes.__html__ = lambda self: unicode(self)
-                    else:
-                        safestring.SafeBytes.__html__ = lambda self: str(self)
+                    safestring.SafeBytes.__html__ = lambda self: six.text_type(self)
 
 
 initial_params = {
